@@ -25,7 +25,7 @@
 
 #include <stdio.h>
 #include <rpcsvc/nis.h>
-#include "nis_print.h"
+#include "../src/nis_print.h"
 
 
 void p_entry_col(entry_col *ecp)
