@@ -30,7 +30,7 @@
 
 #include <stdio.h>
 #include <errno.h>
-#include "dns_group.h"
+#include <grp.h>
 
 
 void dns_setgrent(void)
@@ -50,7 +50,7 @@ struct group *dns_getgrent(void)
 }
 
 
-struct group *dns_getgrgid(gid_t gid)
+struct group *dns_getgrgid(int gid)
 {
     errno = ECONNREFUSED;
     return NULL;
