@@ -30,7 +30,7 @@
 
 #include <stdio.h>
 #include <errno.h>
-#include "dns_passwd.h"
+#include <pwd.h>
 
 
 void dns_setpwent(void)
@@ -50,7 +50,7 @@ struct passwd *dns_getpwent(void)
 }
 
 
-struct passwd *dns_getpwuid(uid_t uid)
+struct passwd *dns_getpwuid(int uid)
 {
     errno = ECONNREFUSED;
     return NULL;
