@@ -27,7 +27,7 @@
 
 #include <stdio.h>
 #include <errno.h>
-#include "dns_protocols.h"
+#include <netdb.h>
 
 
 void dns_setprotoent(int stayopen)
