@@ -27,7 +27,7 @@
 
 #include <stdio.h>
 #include <errno.h>
-#include "dns_rpc.h"
+#include <netdb.h>
 
 
 void dns_setrpcent(int stayopen)
