@@ -30,7 +30,7 @@
 
 #include <stdio.h>
 #include <errno.h>
-#include "dns_shadow.h"
+#include <shadow.h>
 
 
 void dns_setspent(void)
