@@ -29,10 +29,6 @@
 #include "xalloc.h"
 
 
-#ifndef _PATH_PASSWD
-#define _PATH_PASSWD "/etc/passwd"
-#endif
-
 static FILE *pfp = NULL;
 static const char *path_passwd = _PATH_PASSWD;
 
