@@ -26,16 +26,24 @@
 #include <string.h>
 #include "shadow.h"
 #include "misc.h"
+#include "xalloc.h"
+
 
 static FILE *sfp = NULL;
 
 
-struct spwd *sgetspent(char *buf)
+struct spwd *sgetspent(const char *buf)
 {
     static struct spwd spb;
     char *cp, *sp;
+    static char *sbuf = NULL;
 
 
+    if (Xalloc(&sbuf, strlen(buf)+1) == NULL)
+	return NULL;
+
+    strcpy(sbuf, buf);
+
     if (spb.sp_namp)
     {
 	free(spb.sp_namp);
@@ -52,7 +60,7 @@ struct spwd *sgetspent(char *buf)
     spb.sp_inact = spb.sp_expire = -1;
     spb.sp_flag = -1;
 
-    cp = strchr(sp = buf, ':');
+    cp = strchr(sp = sbuf, ':');
     if (cp == NULL)
 	return NULL;
 
@@ -212,11 +220,15 @@ struct spwd *_getspent(void)
 struct spwd *_getspnam(const char *name)
 {
     struct spwd *sp;
+
+    _setspent();
     
     while ((sp = _getspent()) != NULL &&
 	   strcmp(sp->sp_namp, name) != 0)
 	;
 
+    _endspent();
+    
     if (sp == NULL)
 	errno = 0;
     
@@ -236,7 +248,7 @@ static int a_num(char **cp, long val)
 }
 
 
-int sputspent(struct spwd *sp, char *buf)
+int sputspent(const struct spwd *sp, char *buf)
 {
     char *cp;
 
@@ -265,7 +277,7 @@ int sputspent(struct spwd *sp, char *buf)
 }
 
 
-int fputspent(struct spwd *sp, FILE *fp)
+int fputspent(const struct spwd *sp, FILE *fp)
 {
     char buf[1024];
 
@@ -280,7 +292,7 @@ int fputspent(struct spwd *sp, FILE *fp)
 
 
 /* John F. Haugh II shadow-suite compatibility function */
-int putspent(struct spwd *sp, FILE *fp)
+int putspent(const struct spwd *sp, FILE *fp)
 {
     return fputspent(sp, fp);
 }
