@@ -33,8 +33,8 @@
 #include <string.h>
 #include <stdlib.h>
 #include <ctype.h>
+#include <pwd.h>
 #include "yp_misc.h"
-#include "yp_passwd.h"
 #include "rpcsvc/ypclnt.h"
 
 #include "xalloc.h"
@@ -180,7 +180,7 @@ struct passwd *yp_getpwent(void)
 }
 
 
-struct passwd *yp_getpwuid(uid_t uid)
+struct passwd *yp_getpwuid(int uid)
 {
     struct passwd *pw;
     char *map;
